@@ -8,7 +8,8 @@
 "Ojl" <- octonion(jl=1)
 "Okl" <- octonion(kl=1)
 "Oall" <- as.octonion(rep(1,8),single=TRUE)
-"Oim" <- Oall-O1
+"Oim" <- as.octonion(c(0,rep(1,7)),single=TRUE)
+
 
 "H0"  <- quaternion(Re=0)
 "H1"  <- quaternion(Re=1)
@@ -16,5 +17,5 @@
 "Hj"  <- quaternion( j=1)
 "Hk"  <- quaternion( k=1)
 "Hall" <- as.quaternion(rep(1,4),single=TRUE)
-"Him" <- Hall-H1
+"Him" <- as.quaternion(c(0,1,1,1),single=TRUE)
 
